# MIPath

## Installation

```
pip install mipathway
```

## How to use MIPath

You can find an example of a simple analysis in the [vignette](https://github.com/statisticalbiotechnology/mipath/blob/main/MIPath_vignette.ipynb).

## MIPath functions

[Here](https://github.com/statisticalbiotechnology/mipath/blob/main/doc/functions.md) you can find a complete overview of the main functions in the package.

## Help and support

This is a young package, and the documentation is still ongoing. If you have any issues or need help running it, please [open an issue](https://github.com/statisticalbiotechnology/mipath/issues/new) and I will do my best to provide all the guidance and help that I can.
